==> ejc-middlemeasurement-impl-3.0.0-20220428.022448-70-sources.jar: com/ejianc/business/middlemeasurement/bean/RevolvingleasesummaryEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.RevolvingleasesummarydetailEntity;
/**
 * 月度周转工具租赁费结算汇总
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_revolvingleasesummary")
public class RevolvingleasesummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_code")
    private java.lang.String projectCode; // 项目编号
    @TableField(value="statistical_time")
    private java.util.Date statisticalTime; // 统计时间
    @TableField(value="bill_code")
    private java.lang.String billCode; // 编号
    @TableField(value="settle_account")
    private java.math.BigDecimal settleAccount; // 本月结算金额(除税)
    @TableField(value="tax_settle_account")
    private java.math.BigDecimal taxSettleAccount; // 本月结算金额(含税)
    @TableField(value="cumulative_amount")
    private java.math.BigDecimal cumulativeAmount; // 累计结算金额(含税)
    @TableField(value="tax_cumulative_amount")
    private java.math.BigDecimal taxCumulativeAmount; // 累计结算金额(含税)
    @TableField(value="cumulative_payable")
    private java.math.BigDecimal cumulativePayable; // 本月累计应付款金额
    @TableField(value="cumulative_payment")
    private java.math.BigDecimal cumulativePayment; // 本月累计付款金额

    @TableField(exist=false)
    @SubEntity(serviceName="revolvingleasesummarydetailService", pidName = "mid")
    private List<RevolvingleasesummarydetailEntity> revolvingleasesummarydetailEntities = new ArrayList<>(); // 月度周转工具租赁费结算汇总子表
    

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 统计时间
     */
    public java.util.Date getStatisticalTime() {
        return statisticalTime;
    }

    /**
     * 统计时间
     */
    public void setStatisticalTime(java.util.Date statisticalTime) {
        this.statisticalTime = statisticalTime;
    }
    /**
     * 编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 本月结算金额(除税)
     */
    public java.math.BigDecimal getSettleAccount() {
        return settleAccount;
    }

    /**
     * 本月结算金额(除税)
     */
    public void setSettleAccount(java.math.BigDecimal settleAccount) {
        this.settleAccount = settleAccount;
    }
    /**
     * 本月结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettleAccount() {
        return taxSettleAccount;
    }

    /**
     * 本月结算金额(含税)
     */
    public void setTaxSettleAccount(java.math.BigDecimal taxSettleAccount) {
        this.taxSettleAccount = taxSettleAccount;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getCumulativeAmount() {
        return cumulativeAmount;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setCumulativeAmount(java.math.BigDecimal cumulativeAmount) {
        this.cumulativeAmount = cumulativeAmount;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getTaxCumulativeAmount() {
        return taxCumulativeAmount;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setTaxCumulativeAmount(java.math.BigDecimal taxCumulativeAmount) {
        this.taxCumulativeAmount = taxCumulativeAmount;
    }
    /**
     * 本月累计应付款金额
     */
    public java.math.BigDecimal getCumulativePayable() {
        return cumulativePayable;
    }

    /**
     * 本月累计应付款金额
     */
    public void setCumulativePayable(java.math.BigDecimal cumulativePayable) {
        this.cumulativePayable = cumulativePayable;
    }
    /**
     * 本月累计付款金额
     */
    public java.math.BigDecimal getCumulativePayment() {
        return cumulativePayment;
    }

    /**
     * 本月累计付款金额
     */
    public void setCumulativePayment(java.math.BigDecimal cumulativePayment) {
        this.cumulativePayment = cumulativePayment;
    }
    
    /**
     * 月度周转工具租赁费结算汇总子表
     */
    public List<RevolvingleasesummarydetailEntity> getRevolvingleasesummarydetailEntities() {
        return revolvingleasesummarydetailEntities;
    }

    /**
     * 月度周转工具租赁费结算汇总子表
     */
    public void setRevolvingleasesummarydetailEntities(List<RevolvingleasesummarydetailEntity> revolvingleasesummarydetailEntities) {
        this.revolvingleasesummarydetailEntities = revolvingleasesummarydetailEntities;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20220620.074434-108-sources.jar: com/ejianc/business/middlemeasurement/bean/RevolvingleasesummaryEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.RevolvingleasesummarydetailEntity;
/**
 * 月度周转工具租赁费结算汇总
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_revolvingleasesummary")
public class RevolvingleasesummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_code")
    private java.lang.String projectCode; // 项目编号
    @TableField(value="statistical_time")
    private java.util.Date statisticalTime; // 统计时间
    @TableField(value="bill_code")
    private java.lang.String billCode; // 编号
    @TableField(value="settle_account")
    private java.math.BigDecimal settleAccount; // 本月结算金额(除税)
    @TableField(value="tax_settle_account")
    private java.math.BigDecimal taxSettleAccount; // 本月结算金额(含税)
    @TableField(value="cumulative_amount")
    private java.math.BigDecimal cumulativeAmount; // 累计结算金额(含税)
    @TableField(value="tax_cumulative_amount")
    private java.math.BigDecimal taxCumulativeAmount; // 累计结算金额(含税)
    @TableField(value="cumulative_payable")
    private java.math.BigDecimal cumulativePayable; // 本月累计应付款金额
    @TableField(value="cumulative_payment")
    private java.math.BigDecimal cumulativePayment; // 本月累计付款金额

    @TableField(value = "org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value = "org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value = "project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id

    @TableField(exist=false)
    @SubEntity(serviceName="revolvingleasesummarydetailService", pidName = "mid")
    private List<RevolvingleasesummarydetailEntity> revolvingleasesummarydetailEntities = new ArrayList<>(); // 月度周转工具租赁费结算汇总子表
    

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 统计时间
     */
    public java.util.Date getStatisticalTime() {
        return statisticalTime;
    }

    /**
     * 统计时间
     */
    public void setStatisticalTime(java.util.Date statisticalTime) {
        this.statisticalTime = statisticalTime;
    }
    /**
     * 编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 本月结算金额(除税)
     */
    public java.math.BigDecimal getSettleAccount() {
        return settleAccount;
    }

    /**
     * 本月结算金额(除税)
     */
    public void setSettleAccount(java.math.BigDecimal settleAccount) {
        this.settleAccount = settleAccount;
    }
    /**
     * 本月结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettleAccount() {
        return taxSettleAccount;
    }

    /**
     * 本月结算金额(含税)
     */
    public void setTaxSettleAccount(java.math.BigDecimal taxSettleAccount) {
        this.taxSettleAccount = taxSettleAccount;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getCumulativeAmount() {
        return cumulativeAmount;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setCumulativeAmount(java.math.BigDecimal cumulativeAmount) {
        this.cumulativeAmount = cumulativeAmount;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getTaxCumulativeAmount() {
        return taxCumulativeAmount;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setTaxCumulativeAmount(java.math.BigDecimal taxCumulativeAmount) {
        this.taxCumulativeAmount = taxCumulativeAmount;
    }
    /**
     * 本月累计应付款金额
     */
    public java.math.BigDecimal getCumulativePayable() {
        return cumulativePayable;
    }

    /**
     * 本月累计应付款金额
     */
    public void setCumulativePayable(java.math.BigDecimal cumulativePayable) {
        this.cumulativePayable = cumulativePayable;
    }
    /**
     * 本月累计付款金额
     */
    public java.math.BigDecimal getCumulativePayment() {
        return cumulativePayment;
    }

    /**
     * 本月累计付款金额
     */
    public void setCumulativePayment(java.math.BigDecimal cumulativePayment) {
        this.cumulativePayment = cumulativePayment;
    }
    
    /**
     * 月度周转工具租赁费结算汇总子表
     */
    public List<RevolvingleasesummarydetailEntity> getRevolvingleasesummarydetailEntities() {
        return revolvingleasesummarydetailEntities;
    }

    /**
     * 月度周转工具租赁费结算汇总子表
     */
    public void setRevolvingleasesummarydetailEntities(List<RevolvingleasesummarydetailEntity> revolvingleasesummarydetailEntities) {
        this.revolvingleasesummarydetailEntities = revolvingleasesummarydetailEntities;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
}
